@@ -20,7 +20,7 @@ main_package_path = os.path.join(current_dir, package_name)
 if not os.path.exists(main_package_path):
     os.makedirs(main_package_path)
 
-    message = f"⭐ Welcome To {package_name}: Folder created at: {package_path}\n"
+    message = f"⭐ Welcome To {package_name}: Folder created at: {main_package_path}\n"
     print("")
     print(message)
     
