@@ -68,6 +68,8 @@ def validate_delete_parameters_and_return_index(
         TypeError: If any parameter is not of the expected type.
         ValueError: If values violate logical constraints (e.g., both cutoff and keep set).
     """
+    if auto_trim < 1:
+        raise ValueError("⚠️ 'size' parameter must be greater than or equal to 1.")
 
     if not del_list and auto_trim_len is None:
         raise ValueError("del_list Parameter items can't be empty.")
